#!perl
#
# This file is part of Convert-TBX-Min
#
# This software is copyright (c) 2016 by Alan K. Melby.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#

use Test::CPAN::Meta::JSON;
meta_json_ok();
